@@ -1,11 +1,11 @@
-# Copyrights 2003-2013 by [Mark Overmeer].
+# Copyrights 2003-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 package OODoc::Format;
 use vars '$VERSION';
-$VERSION = '2.00';
+$VERSION = '2.01';
 
 use base 'OODoc::Object';
 
@@ -63,6 +63,8 @@ sub showChapter(@)
     my $show_ch  = $args{show_inherited_chapter}    || 'REFER';
     my $show_sec = $args{show_inherited_section}    || 'REFER';
     my $show_ssec= $args{show_inherited_subsection} || 'REFER';
+warn "show $chapter in $manual ($show_ch, $show_sec, ", ref($self), ")\n"
+   if ref $self =~ m/pod/i;
 
     if($manual->inherited($chapter))
     {    return $self if $show_ch eq 'NO';
