@@ -1,11 +1,11 @@
-# Copyrights 2003-2013 by [Mark Overmeer].
+# Copyrights 2003-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 package OODoc::Format::Html;
 use vars '$VERSION';
-$VERSION = '2.00';
+$VERSION = '2.01';
 
 use base 'OODoc::Format';
 
@@ -34,11 +34,12 @@ sub init($)
     $self->{OFH_html} = $html;
     $self->{OFH_jump} = delete $args->{jump_script} || "$html/jump.cgi";
 
-    my $meta  = $self->{OFH_meta}  = delete $args->{html_meta_data} || '';
+    my $meta  = delete $args->{html_meta_data} || '';
     if(my $ss = $self->{OFH_style} = delete $args->{html_stylesheet})
     {   my $base = basename $ss;
         $meta   .= qq[<link rel="STYLESHEET" href="/$base">];
     }
+    $self->{OFH_meta} = $meta;
     $self;
 }
 
@@ -809,20 +810,28 @@ DIAG
     elsif($group eq 'DETAILS')
     {   foreach my $manual (sort $select->($self->manuals))
         {   my $details  = $manual->chapter("DETAILS") or next;
-            my @sections = grep !$manual->inherited($_), $details->sections;
-            next unless @sections || length $details->description;
+            my @sections;
+            foreach my $section ($details->sections)
+            {   my @subsect = grep !$manual->inherited($_) && $_->description
+                  , $section->subsections;
+                push @sections, $section
+                    if @subsect || $section->description;
+            }
+
+            @sections || length $details->description
+                or next;
 
             my $sections = join "\n"
-                             , map { "<li>".$self->link($manual, $_)."</li>" }
-                                @sections;
+              , map { "<li>".$self->link($manual, $_)."</li>" }
+                    @sections;
 
             push @rows, $self->link($manual, $details, "Details in $manual")
-                        . qq[\n<ul>\n$sections</ul>\n]
+              . qq[\n<ul>\n$sections</ul>\n]
         }
     }
     elsif($group eq 'MANUALS')
-    {   @rows = map { $self->link(undef, $_, $_->name) }
-                    sort $select->($self->manuals);
+    {   @rows = map $self->link(undef, $_, $_->name)
+          , sort $select->($self->manuals);
     }
     else
     {   error __x"unknown group {name} as list attribute", name => $group;
@@ -860,8 +869,8 @@ sub templateList($$)
     unless($types eq 'ALL')
     {   my @take   = map { $_ eq 'method' ? '.*method' : $_ }
                          split /[_|]/, $types;
-        local $"   = ')|(';
-        my $regexp = qr/^(@take)$/;
+        local $"   = ')|(?:';
+        my $regexp = qr/^(?:@take)$/;
         $selected  = sub { grep $_->type =~ $regexp, @_ };
     }
 
