@@ -1,10 +1,10 @@
-# Copyrights 2003-2013 by [Mark Overmeer].
+# Copyrights 2003-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 package OODoc::Format::Pod;
 use vars '$VERSION';
-$VERSION = '2.00';
+$VERSION = '2.01';
 
 use base 'OODoc::Format';
 
@@ -256,7 +256,7 @@ sub showSubroutineUse(@)
     $use    =~ s/(.+)/=item $1\n\n/gm;
 
     $output->print($use);
-    $output->print("See ". $self->link($manual, $subroutine)."\n\n")
+    $output->print("Inherited, see ". $self->link($manual, $subroutine)."\n\n")
         if $manual->inherited($subroutine);
 
     $self;
@@ -267,18 +267,21 @@ sub subroutineUse($$)
     my $type       = $subroutine->type;
     my $name       = $self->cleanup($manual, $subroutine->name);
     my $paramlist  = $self->cleanup($manual, $subroutine->parameters);
-    my $params     = length $paramlist ? "($paramlist)" : '()';
+    my $params
+      = !length $paramlist ? '()'
+      : $paramlist =~ m/^[\[<]|[\]>]$/ ? "( $paramlist )"
+      :                      "($paramlist)";
 
     my $class      = $manual->package;
     my $use
-     = $type eq 'i_method' ? qq[\$obj-E<gt>B<$name>$params]
-     : $type eq 'c_method' ? qq[$class-E<gt>B<$name>$params]
-     : $type eq 'ci_method'? qq[\$obj-E<gt>B<$name>$params\n]
-                           . qq[$class-E<gt>B<$name>$params]
-     : $type eq 'function' ? qq[B<$name>$params]
-     : $type eq 'overload' ? qq[overload: B<$name>$params]
-     : $type eq 'tie'      ? qq[B<$name>$params]
-     :                       '';
+      = $type eq 'i_method' ? qq[\$obj-E<gt>B<$name>$params]
+      : $type eq 'c_method' ? qq[$class-E<gt>B<$name>$params]
+      : $type eq 'ci_method'? qq[\$obj-E<gt>B<$name>$params\n]
+                            . qq[$class-E<gt>B<$name>$params]
+      : $type eq 'function' ? qq[B<$name>$params]
+      : $type eq 'overload' ? qq[overload: B<$name>]
+      : $type eq 'tie'      ? qq[B<$name>$params]
+      :                       '';
 
     length $use
         or warn "WARNING: unknown subroutine type $type for $name in $manual";
@@ -474,7 +477,7 @@ sub showSubroutineDescriptionRefer(@)
     my $manual  = $args{manual}                   or panic;
     my $subroutine = $args{subroutine}            or panic;
     my $output  = $args{output}                   or panic;
-    $output->print("\nSee ", $self->link($manual, $subroutine), "\n");
+    $output->print("\nInherited, see ",$self->link($manual, $subroutine),"\n");
 }
 
 sub showSubsIndex() {;}
