@@ -1,11 +1,11 @@
-# Copyrights 2003-2013 by [Mark Overmeer].
+# Copyrights 2003-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 package OODoc::Object;
 use vars '$VERSION';
-$VERSION = '2.00';
+$VERSION = '2.01';
 
 
 use strict;
@@ -40,9 +40,7 @@ sub init($)
 sub extends(;$)
 {   my $self = shift;
     my $ext  = $self->{OO_extends};
-    if(@_)
-    {   push @$ext, @_;
-    }
+    push @$ext, @_;
 
     wantarray ? @$ext : $ext->[0];
 }
