@@ -1,11 +1,11 @@
-# Copyrights 2003-2013 by [Mark Overmeer].
+# Copyrights 2003-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 package OODoc::Parser::Markov;
 use vars '$VERSION';
-$VERSION = '2.00';
+$VERSION = '2.01';
 
 use base 'OODoc::Parser';
 
@@ -164,6 +164,9 @@ sub parse(@)
         if(!$self->inDoc && $line =~ s/^(\s*package\s*([\w\-\:]+)\;)//)
         {   $out->print($1);
             my $package = $2;
+
+            # I would like to use 'our' here, but in some cases, that will
+            # cause compaints about double declaration with our.
             $out->print("\nuse vars '\$VERSION';\n\$VERSION = '$version';\n");
             $out->print($line);
 
@@ -205,7 +208,7 @@ sub parse(@)
                   or $out->print($line);
             }
         }
-        elsif($line =~ m/^=(over|back|item|for|pod|begin|end|head4)\b/ )
+        elsif($line =~ m/^=(over|back|item|for|pod|begin|end|head4|encoding)\b/)
         {   ${$self->{OPM_block}} .= "\n". $line;
             $self->inDoc(1);
         }
@@ -822,7 +825,7 @@ sub cleanupHtml($$$;$)
         {   $type    = 'text';
             $capture = $self->cleanupPod($formatter, $manual, $capture);
         }
-        elsif($type =~ m/^\:html\b/ )
+        elsif($type =~ m/^\:?html\b/ )
         {   $type    = 'html';
             $capture = $self->cleanupHtml($formatter, $manual, $capture, 1);
         }
