@@ -1,11 +1,11 @@
-# Copyrights 2003-2013 by [Mark Overmeer].
+# Copyrights 2003-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 package OODoc::Text;
 use vars '$VERSION';
-$VERSION = '2.00';
+$VERSION = '2.01';
 
 use base 'OODoc::Object';
 
@@ -39,7 +39,7 @@ sub init($)
         or panic "no text container specified for the {pkg} object"
              , pkg => ref $self;
 
-;   # may be undef
+    # may be undef
     $self->{OT_container}= delete $args->{container};
     
     $self->{OT_descr}    = delete $args->{description} || '';
