@@ -1,11 +1,11 @@
-# Copyrights 2003-2013 by [Mark Overmeer].
+# Copyrights 2003-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 package OODoc::Text::Chapter;
 use vars '$VERSION';
-$VERSION = '2.00';
+$VERSION = '2.01';
 
 use base 'OODoc::Text::Structure';
 
@@ -33,7 +33,7 @@ sub init($)
 sub emptyExtension($)
 {   my ($self, $container) = @_;
     my $empty = $self->SUPER::emptyExtension($container);
-    my @sections = map {$_->emptyExtension($empty)} $self->sections;
+    my @sections = map $_->emptyExtension($empty), $self->sections;
     $empty->sections(@sections);
     $empty;
 }
